SJK: Some Jupyter Kernels
=========================

A collection of Jupyter_ kernels for several computer algebra systems.

* Singular_
* Macaulay2_
* Mathematica_
* GAP_
* `Risa/Asir`_

.. _Jupyter: https://jupyter.org
.. _Singular: https://www.singular.uni-kl.de
.. _Macaulay2: http://www2.macaulay2.com/Macaulay2
.. _Mathematica: https://www.wolfram.com/mathematica
.. _GAP: https://www.gap-system.org
.. _Risa/Asir: http://www.math.kobe-u.ac.jp/Asir
